/* bitset.c
 *
 * Minimalist bitset implementation.  No checks at all, use at your own
 * risk!
 *
 * Copyright (C) 2009 ENS Cachan 
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA.
 */

#include <limits.h>
#include <stdbool.h>
#include <stdio.h>
#include <stdlib.h>

#include "bitset.h"

bitset
new_bitset (bword size)
{
  unsigned int length = BWORD_N_WORDS(size);
  bitset b = calloc (length, sizeof(bword));
  int i;

  if (b == NULL)
    {
      fprintf (stderr, "Memory space exceeded.\n");
      exit(1);
    }

  for (i = 0; i < length; i++)
    b[i] = 0;
  
  return b;
}

void
set_bitset (bitset b, bword index)
{
  b[index / BWORD_LENGTH] |= (1 << (index % BWORD_LENGTH));
}

void
unset_bitset (bitset b, bword index)
{
  b[index / BWORD_LENGTH] &= ~(1 << (index % BWORD_LENGTH));
}

bool
test_bitset (const bitset b, bword index)
{
  return b[index / BWORD_LENGTH] & (1 << (index % BWORD_LENGTH));
}

int
count_bitset(const bitset b, bword size)
{
  unsigned int length = BWORD_N_WORDS(size);
  unsigned int i, j, count = 0;

  for (i = 0; i < length; i++)
    if (b[i] != 0)
      for (j = 0; j < BWORD_LENGTH; j++)
        count += (b[i] >> j) & 1;

  return count;    
}

bool
equal_bitsets (const bitset b1, const bitset b2, bword size)
{
  unsigned int length = BWORD_N_WORDS(size);
  unsigned int i;

  for (i = 0; i < length; i++)
    if (b1[i] != b2[i])
      return false;

  return true;
}

/* Compute the union of `b1' and `b2' and put the result in `b1'. */
void
union_bitsets (bitset b1, const bitset b2, bword size)
{
  unsigned int length = BWORD_N_WORDS(size);
  unsigned int i;

  for (i = 0; i < length; i++)
    b1[i] = b1[i] | b2[i];
}
