/* bitset.h
 *
 * Minimalist bitset implementation.  No checks at all, use at your own
 * risk!
 *
 * Copyright (C) 2009 ENS Cachan
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA.
 */

#ifndef BITSET_H
#define BITSET_H

#include <stdbool.h>
#include <limits.h>

typedef unsigned long int bword;
#define BWORD_LENGTH     (CHAR_BIT * sizeof(bword))
#define BWORD_N_WORDS(N) (((N) + (BWORD_LENGTH - 1)) / BWORD_LENGTH)

typedef bword *bitset;

bitset new_bitset (bword size);

void set_bitset (bitset b, bword index);

void unset_bitset (bitset b, bword index);

bool test_bitset (const bitset b, bword index);

int count_bitset(const bitset b, bword size);

bool equal_bitsets (const bitset b1, const bitset b2, bword size);

/* Compute the union of `b1' and `b2' and put the result in `b1'. */
void union_bitsets (const bitset b1, const bitset b2, bword size);

#endif
