/* buta.h
 *
 * Implementation of binary bottom-up tree automata.
 *
 * Copyright (C) 2009 ENS Cachan
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA.
 */

#ifndef BUTA_H
#define BUTA_H
#include <glib.h>
#include <stdio.h>

typedef GHashTable *ruleset;

typedef GHashTable vars;

typedef unsigned int var;

typedef struct
{
  var nvars;            // the variables are numbered from `1' to `nvars'
  int nsyms;            // the symbols are numbered from `0' to `nsyms - 1'
  ruleset* rules;       // the rules table
  vars *initial;        // the initial vars
  char **symbols;       // the names of the symbols
  char **vars;          // the names of the states
} buta;

buta* new_buta(void);

void add_rule(buta*, unsigned int, var, var, var);

inline void set_initial(buta*, var);

void free_buta(buta *);

void relax_ng_print_buta(buta*, FILE*);

#endif
