/* parse.h
 *
 * XML parsing using libxml2.
 *
 * Copyright (C) 2009 ENS Cachan
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA.
 */

#ifndef PARSE_H
#define PARSE_H

#include <stdio.h>
#include <libxml/tree.h>
#include <libxml/xmlstring.h>

/* Return the value of the first attribute named `name', or `NULL' if
 * not found.
 */
xmlChar * attributeWithName (const xmlNodePtr node, const xmlChar *name);

/* Return the first child element named `name', or `NULL' if not
 * found.
 */
inline xmlNodePtr childWithName (const xmlNodePtr node, const xmlChar *name);

/* Return the next sibling element named `name', or `NULL' if not
 * found.
 */
xmlNodePtr siblingWithName (const xmlNodePtr node, const xmlChar *name);

/* Count the children of the provided node. */
inline unsigned int countChildren (const xmlNodePtr node);

/* Count the next siblings of the provided node. */
unsigned int countSiblings (const xmlNodePtr node);

/* Parse from a file descriptor with the provided file name and DTD name. */
dtwa *parse(int, const char *, const char *);

/* Parse an XML file. */
xmlDocPtr xml_tree(int, const char *);

#endif
