/* run.h
 *
 * Run a DTWA on an XML tree.
 *
 * Copyright (C) 2009 ENS Cachan
 *  
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
 * 02110-1301  USA.
 */

#ifndef RUN_H
#define RUN_H

#include <stdbool.h>
#include <libxml/tree.h>

#include "dtwa.h"

/* The navigation type. */
typedef xmlNodePtr (*navigator) (const xmlNodePtr);
typedef type (*typer) (const xmlNodePtr);
typedef struct
{
  navigator nav[NDIRS]; 
  typer     typ;
} tree_nav;

/* Navigate through the XML elements of a binary XML tree. */
extern tree_nav std_nav;

/* Navigate through the XML elements of a binarized XML tree. */
extern tree_nav bin_nav;

/* Navigate through all the nodes (in a DOM sense) of a binary XML tree. */
extern tree_nav xml_nav;

/* Run the automaton on the tree. */
bool run(dtwa*, const xmlDocPtr, tree_nav*, bool);

#endif
